=========
Community
=========

Join the Salt!

There are many ways to participate in and communicate with the Salt community.

Salt has an active IRC channel and a mailing list.

.. _community-mailing-list:

Mailing List
============

Join the `salt-users mailing list`_. It is the best place to ask questions
about Salt and see whats going on with Salt development! The Salt mailing list
is hosted by Google Groups. It is open to new members.

https://groups.google.com/forum/#!forum/salt-users

.. _`salt-users mailing list`: https://groups.google.com/forum/#!forum/salt-users

.. _community-irc:

IRC
===

The ``#salt`` IRC channel is hosted on the popular `Freenode`__ network. You
can use the `Freenode webchat client`__ right from your browser.

`Logs of the IRC channel activity`__ are being collected courtesy of Moritz Lenz.

.. __: http://freenode.net/irc_servers.shtml
.. __: http://webchat.freenode.net/?channels=salt&uio=Mj10cnVlJjk9dHJ1ZSYxMD10cnVl83
.. __: http://irclog.perlgeek.de/salt/

Salt development
----------------

If you wish to discuss the development of Salt itself join us in
``#salt-devel``.

.. _community-github:

Follow on Github
================

The Salt code is developed via Github. Follow Salt for constant updates on what
is happening in Salt development:

|saltrepo|

.. _community-blog:

The Red45 Blog
==============

News and thoughts on Salt and related projects is often posted on Thomas' blog
`The Red45`_:

http://red45.wordpress.com/

.. _`The Red45`: http://red45.wordpress.com/


Example Salt States
===================
The official ``salt-states`` repository is:
https://github.com/saltstack/salt-states

A few examples of salt states from the community:

* https://github.com/blast-hardcheese/blast-salt-states
* https://github.com/kevingranade/kevingranade-salt-state
* https://github.com/uggedal/states
* https://github.com/mattmcclean/salt-openstack/tree/master/salt
* https://github.com/rentalita/ubuntu-setup/
* https://github.com/brutasse/states

Follow on ohloh
===============

https://www.ohloh.net/p/salt

.. include:: hacking.rst
